@@ -101,7 +101,6 @@ class YOLO(object):
             restoring them.
         colors (tf.constant): Color of predicted bounding boxes.
     """
-
     def __init__(self,
                  feature_extractor,
                  grid_h,
@@ -138,7 +137,8 @@ class YOLO(object):
             self.model = self._append_classifier()
         else:
             self.model = self.complete_model
-        self.init_timestamp = "YOLO-" + datetime.now().strftime("%d%m%Y-%H%M%S")
+        self.init_timestamp = "YOLO-" + datetime.now().strftime(
+            "%d%m%Y-%H%M%S")
         self.logdir = os.path.join("logs", self.init_timestamp)
         self.tensorboard = os.path.join(self.logdir, "tensorboard")
         self.ckpt_dir = os.path.join(self.logdir, "ckpts")
@@ -211,24 +211,23 @@ class YOLO(object):
             # Append batch dim.
             boxes_yx = tf.cast(tf.expand_dims(boxes_yx, 0), dtype=tf.float32)
 
-            return tf.image.draw_bounding_boxes(
-                tf.cast(img, dtype=tf.float32), boxes_yx, self.colors)
+            return tf.image.draw_bounding_boxes(tf.cast(img, dtype=tf.float32),
+                                                boxes_yx, self.colors)
 
     def _append_classifier(self):
         self.feature_extractor.add(
             # 1x1 convolution.
-            tf.keras.layers.Conv2D(
-                filters=(self.boxes * (5 + self.n_classes)),
-                kernel_size=(1, 1),
-                strides=(1, 1),
-                padding="same",
-                name="classification_head"))
+            tf.keras.layers.Conv2D(filters=(self.boxes * (5 + self.n_classes)),
+                                   kernel_size=(1, 1),
+                                   strides=(1, 1),
+                                   padding="same",
+                                   name="classification_head"))
 
         # Reshape to specific yolov2 output:
         # (bs, grid, grid, anchors, (x,y,w,h,objectivness, n_classes))
         self.feature_extractor.add(
-            tf.keras.layers.Reshape((self.grid_h, self.grid_w, self.boxes,
-                                     5 + self.n_classes)))
+            tf.keras.layers.Reshape(
+                (self.grid_h, self.grid_w, self.boxes, 5 + self.n_classes)))
 
         return self.feature_extractor
 
@@ -247,10 +246,11 @@ class YOLO(object):
             self.optimizer = tf.keras.optimizers.Adam(lr)
 
         if self.checkpoint is None:
-            self.checkpoint = tf.train.Checkpoint(
-                optimizer=self.optimizer, model=self.model)
-            self.ckpt_manager = tf.train.CheckpointManager(
-                self.checkpoint, self.ckpt_dir, max_to_keep=5)
+            self.checkpoint = tf.train.Checkpoint(optimizer=self.optimizer,
+                                                  model=self.model)
+            self.ckpt_manager = tf.train.CheckpointManager(self.checkpoint,
+                                                           self.ckpt_dir,
+                                                           max_to_keep=5)
 
     def fit(self,
             training_data,
@@ -350,20 +350,19 @@ class YOLO(object):
                 epoch + 1, round(train_loss_avg.result().numpy().item(), 4)))
 
             print("Start validation loop...")
-            self._evaluate(
-                validation_data,
-                iou_threshold=iou_threshold,
-                class_conf_threshold=class_conf_threshold,
-                mlflow=mlflow,
-                tb=True,
-                lambda_coord=lambda_coord,
-                lambda_obj=lambda_obj,
-                lambda_noobj=lambda_noobj,
-                lambda_class=lambda_class,
-                max_outputs=max_outputs,
-                step=step,
-                step_float=step_float,
-                file_writer=eval_file_writer)
+            self._evaluate(validation_data,
+                           iou_threshold=iou_threshold,
+                           class_conf_threshold=class_conf_threshold,
+                           mlflow=mlflow,
+                           tb=True,
+                           lambda_coord=lambda_coord,
+                           lambda_obj=lambda_obj,
+                           lambda_noobj=lambda_noobj,
+                           lambda_class=lambda_class,
+                           max_outputs=max_outputs,
+                           step=step,
+                           step_float=step_float,
+                           file_writer=eval_file_writer)
 
     def coco_metric_format(self, tensor, batch_size, class_conf_threshold,
                            iou_threshold, label):
@@ -390,9 +389,9 @@ class YOLO(object):
             selected_indices = []
             for c in range(self.n_classes):
                 # only include boxes of the current class, with > 0 confidence
-                class_mask = tf.cast(
-                    tf.equal(classes, tf.cast(c, dtype=tf.float32)),
-                    dtype=tf.float32)
+                class_mask = tf.cast(tf.equal(classes,
+                                              tf.cast(c, dtype=tf.float32)),
+                                     dtype=tf.float32)
                 conf_mask = tf.cast(confidence > 0, dtype=tf.float32)
                 mask = class_mask * conf_mask
 
@@ -437,8 +436,9 @@ class YOLO(object):
         self.ckpt_dir = os.path.join(self.logdir, "ckpts")
         if self.ckpt_manager is None:
             raise ModelNotCompiledError("use compile() first.")
-        self.ckpt_manager = tf.train.CheckpointManager(
-            self.checkpoint, self.ckpt_dir, max_to_keep=5)
+        self.ckpt_manager = tf.train.CheckpointManager(self.checkpoint,
+                                                       self.ckpt_dir,
+                                                       max_to_keep=5)
         # if a checkpoint exists, restore the latest checkpoint.
         if self.ckpt_manager.latest_checkpoint:
             self.checkpoint.restore(self.ckpt_manager.latest_checkpoint)
@@ -476,8 +476,9 @@ class YOLO(object):
                 prediction = self.model(x, training=True)
                 end_time = time.time()
                 img_per_second = (end_time - start_time) / batch_size
-                tf.summary.scalar(
-                    "inference_time[s]", img_per_second, step=step)
+                tf.summary.scalar("inference_time[s]",
+                                  img_per_second,
+                                  step=step)
 
                 # Bounding box prediction to tensorboard.
                 tb_prediction = self._prediction_to_tensorboard(
@@ -494,16 +495,15 @@ class YOLO(object):
                     label=True)
 
                 # Loss
-                loss = yolo_loss(
-                    y,
-                    prediction,
-                    self.anchors,
-                    lambda_coord,
-                    lambda_obj,
-                    lambda_noobj,
-                    lambda_class,
-                    iou_threshold=iou_threshold,
-                    step=step)
+                loss = yolo_loss(y,
+                                 prediction,
+                                 self.anchors,
+                                 lambda_coord,
+                                 lambda_obj,
+                                 lambda_noobj,
+                                 lambda_class,
+                                 iou_threshold=iou_threshold,
+                                 step=step)
 
             # Calculate gradient.
             gradient = tape.gradient(loss, self.model.trainable_variables)
@@ -534,14 +534,13 @@ class YOLO(object):
             lambda_noobj (float, optional): [description]. Defaults to 1.0.
             lambda_class (float, optional): [description]. Defaults to 1.0.
         """
-        self._evaluate(
-            dataset,
-            iou_threshold=iou_threshold,
-            class_conf_threshold=class_conf_threshold,
-            lambda_coord=lambda_coord,
-            lambda_obj=lambda_obj,
-            lambda_noobj=lambda_noobj,
-            lambda_class=lambda_class)
+        self._evaluate(dataset,
+                       iou_threshold=iou_threshold,
+                       class_conf_threshold=class_conf_threshold,
+                       lambda_coord=lambda_coord,
+                       lambda_obj=lambda_obj,
+                       lambda_noobj=lambda_noobj,
+                       lambda_class=lambda_class)
 
     def decode_yolo_output(self,
                            predictions,
@@ -615,8 +614,8 @@ class YOLO(object):
         boxes = tf.reshape(boxes, shape=(shape, 4))
 
         # Flatten classes
-        masked_classes = tf.cast(
-            tf.reshape(masked_classes, shape=[shape]), dtype=tf.float32)
+        masked_classes = tf.cast(tf.reshape(masked_classes, shape=[shape]),
+                                 dtype=tf.float32)
 
         # Flatten class_confidence.
         masked_confidence = tf.reshape(masked_confidence, shape=[shape])
@@ -627,8 +626,8 @@ class YOLO(object):
 
         # apply multiclass NMS
         for c in range(n_classes):
-            class_mask = tf.cast(
-                tf.math.equal(masked_classes, c), dtype=tf.float32)
+            class_mask = tf.cast(tf.math.equal(masked_classes, c),
+                                 dtype=tf.float32)
             score_mask = tf.cast(masked_confidence > 0, dtype=tf.float32)
             mask = class_mask * score_mask
             # Prunes away boxes that have high intersection-over-union (IOU)
@@ -669,9 +668,9 @@ class YOLO(object):
             selected_indices = []
             for c in range(self.n_classes):
                 # only include boxes of the current class, with > 0 confidence
-                class_mask = tf.cast(
-                    tf.equal(classes, tf.cast(c, dtype=tf.float32)),
-                    dtype=tf.float32)
+                class_mask = tf.cast(tf.equal(classes,
+                                              tf.cast(c, dtype=tf.float32)),
+                                     dtype=tf.float32)
                 conf_mask = tf.cast(confidence > 0, dtype=tf.float32)
                 mask = class_mask * conf_mask
 
@@ -689,8 +688,8 @@ class YOLO(object):
             # TODO draw_boundin_boxes does not support labels right now.
             #selected_classes = tf.gather(classes, selected_indices)
             #selected_confidence = tf.gather(confidence, selected_indices)
-            selected_boxes = tf.cast(
-                tf.expand_dims(selected_boxes, 0), dtype=tf.float32)
+            selected_boxes = tf.cast(tf.expand_dims(selected_boxes, 0),
+                                     dtype=tf.float32)
 
             # Swap xy coordinates for bullshit tensorflow draw_bounding_boxes.
             x1 = selected_boxes[..., 0:1]
@@ -700,9 +699,8 @@ class YOLO(object):
             boxes_yx = tf.concat([y1, x1, y2, x2], axis=-1)
 
             tb_img = tf.image.draw_bounding_boxes(
-                tf.cast(
-                    tf.expand_dims(input_img[img, :, :, :], 0),
-                    dtype=tf.float32), boxes_yx, self.colors)
+                tf.cast(tf.expand_dims(input_img[img, :, :, :], 0),
+                        dtype=tf.float32), boxes_yx, self.colors)
             tb_imgs.append(tb_img)
 
         tb_output = tf.concat(tb_imgs, axis=0)
@@ -739,17 +737,16 @@ class YOLO(object):
             # Set training false, so that BN uses the mean and variance of
             # its moving statistics, learned during training.
             val_logits = self.model(images, training=False)
-            loss = yolo_loss(
-                labels,
-                val_logits,
-                self.anchors,
-                lambda_coord=lambda_coord,
-                lambda_obj=lambda_obj,
-                lambda_noobj=lambda_noobj,
-                lambda_class=lambda_class,
-                iou_threshold=iou_threshold,
-                step=step,
-                is_training=False)
+            loss = yolo_loss(labels,
+                             val_logits,
+                             self.anchors,
+                             lambda_coord=lambda_coord,
+                             lambda_obj=lambda_obj,
+                             lambda_noobj=lambda_noobj,
+                             lambda_class=lambda_class,
+                             iou_threshold=iou_threshold,
+                             step=step,
+                             is_training=False)
             val_loss_avg.update_state(loss)
 
             if tb:
@@ -759,13 +756,14 @@ class YOLO(object):
                     images, val_logits, max_outputs, step, iou_threshold,
                     class_conf_threshold)
                 with file_writer.as_default():
-                    tf.summary.image(
-                        "validation", tb_prediction_val, step=step)
+                    tf.summary.image("validation",
+                                     tb_prediction_val,
+                                     step=step)
 
             # Coco mAP validation metrics.
             # Effective batch size. Last batch could contain fewer elements.
-            eff_bs = tf.cast(
-                tf.shape(images)[0], dtype=tf.int32).numpy().item()
+            eff_bs = tf.cast(tf.shape(images)[0],
+                             dtype=tf.int32).numpy().item()
             bboxs, cat_ids, scores = self.coco_metric_format(
                 val_logits, eff_bs, class_conf_threshold, iou_threshold, False)
             # Iterate over all detections per image.
@@ -844,23 +842,53 @@ class YOLO(object):
         metrics = compute_coco_metrics(groundtruth_dict, detections_list)
         if tb:
             with file_writer.as_default():
-                tf.summary.scalar(
-                    "total_loss", val_loss_avg.result(), step=step)
+                tf.summary.scalar("total_loss",
+                                  val_loss_avg.result(),
+                                  step=step)
                 for key in metrics:
                     tf.summary.scalar(key, metrics[key], step=step)
             file_writer.flush()
 
         if mlflow:
             # Convert to native python type (db).
-            mlflow.log_metric(
-                "mAP50IOU",
-                metrics["Precision/mAP@.50IOU"].item(),
-                step=step_float)
-            mlflow.log_metric(
-                "AR100", metrics["Recall/AR@100"].item(), step=step_float)
-            mlflow.log_metric(
-                "val_loss",
-                val_loss_avg.result().numpy().item(),
-                step=step_float)
+            mlflow.log_metric("mAP",
+                              metrics["Precision/mAP"].item(),
+                              step=step_float)
+            mlflow.log_metric("mAP50IOU",
+                              metrics["Precision/mAP@.50IOU"].item(),
+                              step=step_float)
+            mlflow.log_metric("mAP75IOU",
+                              metrics["Precision/mAP@.75IOU"].item(),
+                              step=step_float)
+            mlflow.log_metric("mAPsmall",
+                              metrics["Precision/mAP (small)"].item(),
+                              step=step_float)
+            mlflow.log_metric("mAPmedium",
+                              metrics["Precision/mAP (medium)"].item(),
+                              step=step_float)
+            mlflow.log_metric("mAPlarge",
+                              metrics["Precision/mAP (large)"].item(),
+                              step=step_float)
+            mlflow.log_metric("AR1",
+                              metrics["Recall/AR@1"].item(),
+                              step=step_float)
+            mlflow.log_metric("AR10",
+                              metrics["Recall/AR@10"].item(),
+                              step=step_float)
+            mlflow.log_metric("AR100",
+                              metrics["Recall/AR@100"].item(),
+                              step=step_float)
+            mlflow.log_metric("AR100small",
+                              metrics["Recall/AR@100 (small)"].item(),
+                              step=step_float)
+            mlflow.log_metric("AR100medium",
+                              metrics["Recall/AR@100 (medium)"].item(),
+                              step=step_float)
+            mlflow.log_metric("AR100large",
+                              metrics["Recall/AR@100 (large)"].item(),
+                              step=step_float)
+            mlflow.log_metric("val_loss",
+                              val_loss_avg.result().numpy().item(),
+                              step=step_float)
         print("...Done - loss {}\n".format(
             round(val_loss_avg.result().numpy().item(), 4)))
\ No newline at end of file
